# to init
from .covid_news import CoronavirusNews
from .en_world_news import EnglishWorldNews
from .protests import Protests
from .travel import TravelWarnings
from .terror_monitor import TerrorNews
from .tr_world_news import TranslatedWorldNews
from .simple_search import SimpleSearch
from .hospital_news import HospitalNews
